Python API for spead2
=====================

.. py:module:: spead2

This documentation does not cover all the classes and methods in the module.
Instead, it documents those that are expected to be commonly used by the user,
and omits those designed for the classes to communicate with each other or
with the C++ backend.

.. toctree::
   :maxdepth: 2

   py-flavour
   py-protocol
   py-items
   py-thread-pools
   py-recv
   py-send
   py-logging
